@@ -1,9 +1,8 @@
-dd_loglik = function(trpars1,pars2,brts,missnumspec)
+dd_loglik = function(pars1,pars2,brts,missnumspec)
 {
 # brts = branching times (positive, from present to past)
 # - max(brts) = crown age
 # - min(brts) = most recent branching time
-# tr is transformed
 # - pars1[1] = la = (initial) speciation rate
 # - pars1[1] = mu = extinction rate
 # - pars1[1] = K = carrying capacity
@@ -13,20 +12,22 @@ dd_loglik = function(trpars1,pars2,brts,missnumspec)
 #  . ddep==2 : exponential dependence in speciation rate
 #  . ddep==3 : linear dependence in extinction rate
 #  . ddep==4 : exponential dependence in extinction rate
+# - pars2[3] = cond = conditioning on non-extinction of the phylogeny
 # missnumspec = number of missing species    
 
-pars1 = trpars1/(1 - trpars1)
 abstol = 1e-16
 reltol = 1e-10 
-brts = -sort(as.numeric(brts),decreasing = TRUE)
+brts = -sort(abs(as.numeric(brts)),decreasing = TRUE)
 if(sum(brts == 0) == 0) { brts[length(brts) + 1] = 0 }
 S = length(brts)
-if(max(trpars1) > 1 || min(trpars1) < 0 || trpars1[1] <= trpars1[2]) { loglik = -Inf } else
+if(min(pars1) < 0 || pars1[1] <= pars1[2]) { loglik = -Inf } else
 {
     la = pars1[1]
     mu = pars1[2]
     K = pars1[3]
     ddep = pars2[2]
+    cond = pars2[3]
+
     if(ddep == 1 && ceiling(la/(la - mu) * K) < S) { loglik = -Inf } else
     {
        if(ddep == 1) { lx = min(ceiling(la/(la - mu) * K),round(pars2[1])) } else { lx = round(pars2[1]) }
@@ -52,18 +53,20 @@ if(max(trpars1) > 1 || min(trpars1) < 0 || trpars1[1] <= trpars1[2]) { loglik =
        }    
        if(probs[1+missnumspec]<=0) { loglik = -Inf } else
        {        
-          loglik = loglik + log(probs[1 + missnumspec]) - log(S - 1) + log(S + missnumspec + 1) - lgamma(S + missnumspec + 2) + lgamma(S + 2) + lgamma(missnumspec + 1)
+          loglik = loglik + log(probs[1 + missnumspec]) - log(S - 1) + log(S + missnumspec - 1) - lgamma(S + missnumspec + 2) + lgamma(S + 2) + lgamma(missnumspec + 1)
   
-          probs = rep(0,lx)
-          probs[1] = 1
-          # change if other species at crown age
-          k = 2
-          t1 = brts[1] 
-          t2 = brts[S]
-          y = lsoda(probs,c(t1,t2),dd_loglik_rhs,c(pars1,k,ddep),rtol = reltol,atol = abstol);
-          probs = y[2,2:(lx+1)]
-          aux = (2:(lx+1)) * (3:(lx+2))/6
-          logliknorm = log(sum(probs/aux))
+          if(cond == TRUE)
+          {
+             probs = rep(0,lx)
+             probs[1] = 1 # change if other species at crown age
+             k = 2
+             t1 = brts[1] 
+             t2 = brts[S]
+             y = lsoda(probs,c(t1,t2),dd_loglik_rhs,c(pars1,k,ddep),rtol = reltol,atol = abstol);
+             probs = y[2,2:(lx+1)]
+             aux = (2:(lx+1)) * (3:(lx+2))/6
+             logliknorm = log(sum(probs/aux))
+          } else { logliknorm = 0 }
           loglik = loglik - logliknorm
        }
     }
